aboutsummaryrefslogtreecommitdiffstats
path: root/ports/darwin/guts/setxattr.c
diff options
context:
space:
mode:
Diffstat (limited to 'ports/darwin/guts/setxattr.c')
-rw-r--r--ports/darwin/guts/setxattr.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/ports/darwin/guts/setxattr.c b/ports/darwin/guts/setxattr.c
index 3c8fd3d..10ffba4 100644
--- a/ports/darwin/guts/setxattr.c
+++ b/ports/darwin/guts/setxattr.c
@@ -1,12 +1,12 @@
/*
- * Copyright (c) 2011 Wind River Systems; see
+ * Copyright (c) 2014 Wind River Systems; see
* guts/COPYRIGHT for information.
*
* int setxattr(const char *pathname, const char *name, const void *value, size_t size, u_int32_t position, int options)
* int rc = -1;
*/
- rc = real_setxattr(pathname, name, value, size, position, options);
+ rc = shared_setxattr(path, -1, name, value, size, position, options);
/* return rc;
* }
@@ -1,12 +1,12 @@
* guts/COPYRIGHT for information.
*
- * int setxattr(const char *pathname, const char *name, const void *value, size_t size, u_int32_t position, int options)
+ * int setxattr(const char *path, const char *name, const void *value, size_t size, u_int32_t position, int options)
* int rc = -1;
*/